==> kdeedu-3.0.1.tar.bz2: kdeedu-3.0.1/kstars/kstars/kssun.h <==
/***************************************************************************
                          kssun.h  -  K Desktop Planetarium
                             -------------------
    begin                : Sun Jul 22 2001
    copyright            : (C) 2001 by Jason Harris
    email                : jharris@30doradus.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSSUN_H
#define KSSUN_H

#include <qstring.h>
#include "dms.h"
#include "ksplanet.h"

/**
	*Child class of KSPlanet; encapsulates information about the Sun.
	*@short Provides necessary information about the Sun.
  *@author Jason Harris
  *@version 0.9
  */

class KSSun : public KSPlanet  {
public:
/**
	*Default constructor.  Defines constants needed by findPosition().
	*Sets Ecliptic coordinates appropriate for J2000.
	*/
	KSSun();

/**
	*Constructor.  Defines constants needed by findPosition().
	*Sets Ecliptic coordinates according to Epoch given as the argument.
	*@param Epoch current Julian Date
	*/
	KSSun( long double Epoch );

/**
	*Destructor (empty)
	*/
	~KSSun() {}

/**
	*Determine RA, Dec coordinates for the Epoch given in the argument.
	*@param Epoch current Julian Date
	*/
	bool findPosition( long double jd );	

private:
	long double JD0;
	double eclong0, plong0, e0;
};

#endif

==> kdeedu-3.1.3.tar.bz2: kdeedu-3.1.3/kstars/kstars/kssun.h <==
/***************************************************************************
                          kssun.h  -  K Desktop Planetarium
                             -------------------
    begin                : Sun Jan 29 2002
    copyright            : (C) 2002 by Mark Hollomon
    email                : mhh@mindspring.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSSUN_H
#define KSSUN_H

#include <qstring.h>
#include "dms.h"
#include "ksplanet.h"

/**
	*Child class of KSPlanetBase; encapsulates information about the Sun.
	*@short Provides necessary information about the Sun.
  *@author Mark Hollomon
  *@version 0.9
  */

class KStars;
class KSSun : public KSPlanet  {
public:
/**
	*Default constructor.  Defines constants needed by findPosition().
	*Sets Ecliptic coordinates appropriate for J2000.
	*/
	KSSun(KStars *ks, QString fn = "");

/**
	*Destructor (empty)
	*/
	virtual ~KSSun() {}

	/**
	 *  reimplemented from KSPlanet
	 */
	virtual bool loadData();

/**
	*Determine RA, Dec coordinates for the Epoch given in the argument.
	*@param Epoch current Julian Date
	*/
	virtual bool findPosition( const KSNumbers *num, const KSPlanetBase *Earth=NULL );	
};

#endif
